-- Read the docs: https://www.lunarvim.org/docs/configuration
-- Video Tutorials: https://www.youtube.com/watch?v=sFA9kX-Ud_c&list=PLhoH5vyxr6QqGu0i7tt_XoVK9v-KvZ3m6
-- Forum: https://www.reddit.com/r/lunarvim/
-- Discord: https://discord.com/invite/Xb9B4Ny
--

-- Generic Custom Settings
local set = vim.opt
set.relativenumber = true
set.mouse = ""
set.cursorline = true
set.termguicolors = true
set.winblend = 0
set.wildoptions = "pum"
set.pumblend = 0
lvim.transparent_window = true
vim.g.codestats_api_key = 'SFMyNTY.WjJGcFpYUjUjI01qSXhPVFU9.fMtCrS4QvdQKCgS_pasnqpWGUyrk3At646kPkN7LIn8'

-- Custom Plugins
lvim.plugins = {
  { "catppuccin/nvim", name = "catppuccin", priority = 1000 },
  { "yamatsum/nvim-cursorline" },
  { url = "https://gitlab.com/code-stats/code-stats-vim.git"}
}

-- Theme Overrides
require("catppuccin").setup({
  flavour = "macchiato", -- latte, frappe, macchiato, mocha
  background = { -- :h background
    light = "latte",
    dark = "mocha",
  },
  transparent_background = true, -- disables setting the background color.
  show_end_of_buffer = false, -- shows the '~' characters after the end of buffers
  term_colors = false, -- sets terminal colors (e.g. `g:terminal_color_0`)
  dim_inactive = {
    enabled = true, -- dims the background color of inactive window
    shade = "dark",
    percentage = 0.15, -- percentage of the shade to apply to the inactive window
  },
  styles = { -- Handles the styles of general hi groups (see `:h highlight-args`):
    comments = { "italic" }, -- Change the style of comments
    conditionals = { "italic" },
    loops = {},
    functions = {},
    keywords = {},
    strings = {},
    variables = {},
    numbers = {},
    booleans = {},
    properties = {},
    types = {},
    operators = {},
    -- miscs = {}, -- Uncomment to turn off hard-coded styles
  },
  color_overrides = {},
  custom_highlights = {},
})

vim.cmd[[colorscheme catppuccin]]
lvim.colorscheme = "catppuccin"

-- DAP
local dap = require('dap')
dap.configurations.typescript = {
    {
        name = "Launch",
        type = "node2",
        request = "launch",
        cwd = vim.loop.cwd(),
        runtimeArgs = { "-r", "ts-node/register" },
        runtimeExecutable = "node",
        args = {"--inspect", "${file}"},
        sourceMaps = true,
        skipFiles = { "<node_internals>/**", "node_modules/**" },
    }, {
        name = "Attach",
        type = "node2",
        request = "attach",
        processId = require 'dap.utils'.pick_process,
    }

}
dap.adapters.node2 = {
  type = 'executable',
  command = 'node',
  args = {os.getenv('HOME') .. '/dev/microsoft/vscode-node-debug2/out/src/nodeDebug.js'},
}

-- cursorline
require('nvim-cursorline').setup {
  cursorline = {
    enable = true,
    timeout = 1000,
    number = false,
  },
  cursorword = {
    enable = true,
    min_length = 3,
    hl = { underline = true },
  }
}
